IntramSdkPayment class

Constructors

IntramSdkPayment(String publicKey, String privateKey, String secretKey, String merchantKey, bool requiredUserInformation, Map<String, dynamic> customUserInformation)

Properties

customUserInformation Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchantKey String
final
privateKey String
final
publicKey String
final
requiredUserInformation bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
final

Methods

makePayment(BuildContext context, int amount, bool sandbox, String storeName, String color, String logoUrl, {String? callbackUrl}) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited